@@ -269,6 +269,9 @@ stuff_changed_cb (WirelessSecurity *sec, gpointer user_data)
 	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (priv->sec_combo), &iter))
 		gtk_tree_model_get (model, &iter, S_SEC_COLUMN, &sel_sec, -1);
 
+	if (sel_sec)
+		wireless_security_unref (sel_sec);
+
 	if (sel_sec != sec)
 		return;
 
@@ -462,7 +465,7 @@ connection_combo_init (NMAWifiDialog *self, NMConnection *connection)
 
 		gtk_list_store_append (store, &tree_iter);
 		gtk_list_store_set (store, &tree_iter,
-		                    C_NAME_COLUMN, _("New..."),
+		                    C_NAME_COLUMN, _("New…"),
 		                    C_NEW_COLUMN, TRUE, -1);
 
 		gtk_list_store_append (store, &tree_iter);
@@ -1154,7 +1157,7 @@ internal_init (NMAWifiDialog *self,
 		if (ssid)
 			esc_ssid = nm_utils_ssid_to_utf8 (g_bytes_get_data (ssid, NULL), g_bytes_get_size (ssid));
 
-		tmp = g_strdup_printf (_("Passwords or encryption keys are required to access the Wi-Fi network '%s'."),
+		tmp = g_strdup_printf (_("Passwords or encryption keys are required to access the Wi-Fi network “%s”."),
 		                       esc_ssid ? esc_ssid : "<unknown>");
 		gtk_window_set_title (GTK_WINDOW (self), _("Wi-Fi Network Authentication Required"));
 		label = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s",
@@ -1388,8 +1391,8 @@ nma_wifi_dialog_init (NMAWifiDialog *self)
 
 	priv->builder = gtk_builder_new ();
 
-	if (!gtk_builder_add_from_file (priv->builder, UIDIR "/wifi.ui", &error)) {
-		g_warning ("Couldn't load builder file: %s", error->message);
+	if (!gtk_builder_add_from_resource (priv->builder, "/org/freedesktop/network-manager-applet/wifi.ui", &error)) {
+		g_warning ("Couldn't load builder resource: %s", error->message);
 		g_error_free (error);
 	}
 }
